/**
 * cygicons.h : icon resource id values
 *
 * Copyright 2007 by Charles S. Wilson <cygwin@cygwin.com>
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * See the COPYING file for license information.
 */
#ifndef CYGUTILS_CYGICONS_H
#define CYGUTILS_CYGICONS_H

#define IDI_CYGWIN        101
#define IDI_CYGWIN_RED    102
#define IDI_CYGWIN_BLUE   103
#define IDI_CYGWIN_CYAN   104
#define IDI_CYGWIN_PURPLE 105
#define IDI_CYGWIN_YELLOW 106
#define IDI_CYGWIN_SHINY  107
#define IDI_CYGWIN_G      108
#define IDI_CYGWIN_GS     109
#define IDI_CYGWIN_KDE    110
#define IDI_CYGWIN_HIPPO  111

#endif /* !CYGUTILS_CYGICONS_H */

